@@ -6,23 +6,12 @@ from halo import Halo  # type: ignore
 from humanfriendly import format_size, parse_size  # type: ignore
 from timeago import format as timeago_format  # type: ignore
 
-from treebeard.conf import (
-    signup_endpoint,
-    treebeard_web_url,
-)
-from treebeard.helper import (
-    get_config_path,
-    get_treebeard_env,
-    set_credentials,
-)
+from treebeard.conf import signup_endpoint, treebeard_env, treebeard_web_url
+from treebeard.helper import set_credentials
 from treebeard.version import get_version
 
-config_path = get_config_path()
-
-treebeard_env = get_treebeard_env()
-
-project_id = treebeard_env["project_id"]
-notebook_id = treebeard_env["notebook_id"]
+project_id = treebeard_env.project_id
+notebook_id = treebeard_env.notebook_id
 
 warnings.filterwarnings(
     "ignore", "Your application has authenticated using end user credentials"
