@@ -8,10 +8,9 @@ from halo import Halo  # type: ignore
 from humanfriendly import format_size, parse_size  # type: ignore
 from timeago import format as timeago_format  # type: ignore
 
-from treebeard.conf import service_status_endpoint
+from treebeard.conf import service_status_endpoint, treebeard_env
 from treebeard.helper import (
-    get_config_path,
-    get_treebeard_env,
+    CliContext,
     check_for_updates,
     get_service_status_message,
 )
@@ -19,16 +18,12 @@ from treebeard.notebooks.commands import cancel, run, status
 from treebeard.other.commands import configure, info, version
 from treebeard.secrets.commands import secrets
 
-config_path = get_config_path()
-
-treebeard_env = get_treebeard_env()
-
 msg = get_service_status_message(service_status_endpoint)
 if msg:
     click.echo(click.style(msg, fg="red"), err=True)
 
-project_id = treebeard_env["project_id"]
-notebook_id = treebeard_env["notebook_id"]
+project_id = treebeard_env.project_id
+notebook_id = treebeard_env.notebook_id
 
 warnings.filterwarnings(
     "ignore", "Your application has authenticated using end user credentials"
@@ -36,7 +31,10 @@ warnings.filterwarnings(
 
 
 @click.group()
-def cli():
+@click.option("--debug/--no-debug", default=False)
+@click.pass_context
+def cli(ctx: Any, debug: bool):
+    ctx.obj = CliContext(debug=debug)
     pass
 
 
